@@ -1,6 +1,6 @@
 /**************************************************************************
  *  PipeWalker game (http://pipewalker.sourceforge.net)                   *
- *  Copyright (C) 2007-2010 by Artem A. Senichev <artemsen@gmail.com>     *
+ *  Copyright (C) 2007-2012 by Artem Senichev <artemsen@gmail.com>        *
  *                                                                        *
  *  This program is free software: you can redistribute it and/or modify  *
  *  it under the terms of the GNU General Public License as published by  *
@@ -19,64 +19,23 @@
 #pragma once
 
 //Standard libraries
-#include <stdlib.h>
-#include <stdio.h>
 #include <cassert>
-#include <exception>
 #include <string>
 #include <map>
-#include <list>
 #include <vector>
 #include <iterator>
-#include <string.h>
+#include <fstream>
+#include <complex>
+#include <algorithm>
+
+using namespace std;
 
 #ifdef WIN32
 #include <windows.h>
 #endif	//WIN32
 
-using namespace std;
-
-#ifndef PACKAGE_STRING
-	#define PACKAGE_STRING	"PipeWalker"
-#endif	//PACKAGE_STRING
-
-#ifndef DIR_GAMEDATA
-	#define DIR_GAMEDATA	"./data/"
-#endif	//DIR_GAMEDATA
-
-#define PW_SCREEN_WIDTH		490	///< Initial screen (main window) width
-#define PW_SCREEN_HEIGHT	580	///< Initial screen (main window) height
-
-//OpenGL library
-#include <GL/gl.h>
-
-#ifndef __MINGW32__
-#pragma warning(disable: 4996)	///The POSIX name for this item is deprecated
-#endif	//__MINGW32__
-
-//Byte order
-#if defined(__hppa__) || defined(__m68k__) || defined(mc68000) || defined(__M68K) || \
-	(defined(__MIPS__) && defined(__MISPEB__)) || \
-	defined(__ppc__) || defined(__POWERPC__) || defined(__PPC) || defined(__sparc__)
-	#define PW_BYTEORDER_BIG_ENDIAN 1
-#else
-	#define PW_BYTEORDER_LITTLE_ENDIAN 1
-#endif
-
-#include "exception.h"
+#include <SDL/SDL.h>
 
 
-/**
- * Check for OpenGL error
- * \return true if errors exist
- */
-inline bool CheckGLError()
-{
-	bool res = true;
-	GLenum glErr;
-	while ((glErr = glGetError()) != GL_NO_ERROR) {
-		fprintf(stderr, "OpenGL error: 0x\n", glErr);
-		res = false;
-	}
-	return res;
-}
+#define PW_SCREEN_WIDTH		520	///< Initial screen (main window) width
+#define PW_SCREEN_HEIGHT	620	///< Initial screen (main window) height
