@@ -1,6 +1,6 @@
 /**************************************************************************
  *  PipeWalker game (http://pipewalker.sourceforge.net)                   *
- *  Copyright (C) 2007-2010 by Artem A. Senichev <artemsen@gmail.com>     *
+ *  Copyright (C) 2007-2012 by Artem Senichev <artemsen@gmail.com>        *
  *                                                                        *
  *  This program is free software: you can redistribute it and/or modify  *
  *  it under the terms of the GNU General Public License as published by  *
@@ -20,50 +20,44 @@
 
 #include "common.h"
 
-class CGame;
-
-#ifdef _MSC_VER
-#pragma warning(disable: 4512)	//assignment operator could not be generated
-#endif // _MSC_VER
+class level;
 
 
-class CExplosion
+class explosion
 {
 public:
 	/**
-	 * Constructor
-	 * \param game the game instance
-	 * \param x an initial X explosion position
-	 * \param y an initial Y explosion position
+	 * Create winner animation
+	 * \param lvl current level
 	 */
-	CExplosion(CGame& game, const float x, const float y);
+	void create(const level& lvl);
+
+	/**
+	 * Free winner animation
+	 */
+	inline void free() { _particles.clear(); }
 
 	/**
 	 * Render explosion
 	 */
-	void Render();
-
-private:
-	/**
-	 * Renew explosion
-	 */
-	void Renew();
+	void draw(const float alpha);
 
 private:
 	//! Particles description
-	struct PARTICLE {
-		float	Life;		///< Life value
-		float	FadeSpeed;	///< Fade speed
-		float	PosX;		///< Position by X axis
-		float	PosY;		///< Position by Y axis
-		float	SpeedX;		///< Speed by X axis
-		float	SpeedY;		///< Speed by Y axis
+	struct particle {
+		unsigned long life;   ///< Life time in ms
+		unsigned long stime;  ///< Creation (start) time in ms
+		float         x;      ///< Position by X axis
+		float         y;      ///< Position by Y axis
+		float         speed;  ///< Speed
+		float         init_x; ///< Initial position by X axis
+		float         init_y; ///< Initial position by Y axis
 	};
 
-	vector<PARTICLE>	_Particles;	///< Particle Array
-	float				_X;			///< Initial X explosion position
-	float				_Y;			///< Initial Y explosion position
-	float				_Force;		///< Explosion force
+private:
+	particle create(const float x, const float y) const;
 
-	CGame&				_Game;		///< Game instance
+private:
+	typedef vector<particle> particles;
+	particles _particles; ///< Particle Array
 };
